# What is GaiWEB
It is A flask app ,u can use gemini api to  on web.
-upload image
-url
-chat
# instlation
```
pip install gaiweb
```
# use
```
gaiweb 
gaiweb --apikey youerApikey
```
# 喜欢关注python学霸公众号